@@ -4,9 +4,6 @@ from decimal import Decimal
 from trytond.model import fields, Check
 from trytond.pool import Pool, PoolMeta
 from trytond.transaction import Transaction
-from trytond import backend
-
-__all__ = ['Move']
 
 
 def _get_field(type_):
@@ -16,8 +13,7 @@ def _get_field(type_):
         return 'out_anglo_saxon_quantity'
 
 
-class Move:
-    __metaclass__ = PoolMeta
+class Move(metaclass=PoolMeta):
     __name__ = 'stock.move'
     in_anglo_saxon_quantity = fields.Float('Input Anglo-Saxon Quantity',
         required=True)
@@ -34,28 +30,12 @@ class Move:
         cls._sql_constraints += [
             ('check_in_anglo_saxon_quantity',
                 Check(t, t.quantity >= t.in_anglo_saxon_quantity),
-                'Anglo-Saxon quantity can not be greater than quantity.'),
+                'account_stock_anglo_saxon.msg_move_quantity_greater'),
             ('check_out_anglo_saxon_quantity',
                 Check(t, t.quantity >= t.out_anglo_saxon_quantity),
-                'Anglo-Saxon quantity can not be greater than quantity.'),
+                'account_stock_anglo_saxon.msg_move_quantity_greater'),
             ]
 
-    @classmethod
-    def __register__(cls, module_name):
-        cursor = Transaction().connection.cursor()
-        TableHandler = backend.get('TableHandler')
-
-        super(Move, cls).__register__(module_name)
-        table = TableHandler(cls, module_name)
-
-        # Migration from 2.8: split anglo_saxon_quantity
-        if table.column_exist('anglo_saxon_quantity'):
-            cursor.execute('UPDATE "' + cls._table + '" '
-                'SET in_anglo_saxon_quantity = anglo_saxon_quantity, '
-                'out_anglo_saxon_quantity = anglo_saxon_quantity')
-            table.drop_constraint('check_anglo_saxon_quantity')
-            table.drop_column('anglo_saxon_quantity')
-
     @staticmethod
     def default_in_anglo_saxon_quantity():
         return 0.0
@@ -81,7 +61,7 @@ class Move:
                 Decimal(str(self.quantity)) * (unit_price - cost_price))
             if self.company.currency.is_zero(amount):
                 return lines
-            account = self.product.account_stock_supplier_used
+            account = self.product.account_stock_in_used
             for move_line in lines:
                 if move_line.account == account:
                     break
@@ -189,7 +169,8 @@ class Move:
     def copy(cls, moves, default=None):
         if default is None:
             default = {}
-        default = default.copy()
+        else:
+            default = default.copy()
         for prefix in ('in_', 'out_'):
             default.setdefault(prefix + 'anglo_saxon_quantity',
                 getattr(cls, 'default_%sanglo_saxon_quantity' % prefix)())
